@@ -14,7 +14,7 @@ def wipe_id_fields_on_django_lt_17(fields):
     Django 1.7, all the FKs appear as `other_model` and `other_model_id`.
     """
     if DJANGO_LT_17:
-        return filter(lambda n: not n.endswith('_id'), fields)
+        return [field for field in fields if not field.endswith('_id')]
     return fields
 
 
